@@ -120,6 +120,8 @@ public:
     Q_INVOKABLE QJSValue arrivalMapArguments() const;
     /** Map page arguments for the departure side, if this is a location change element. */
     Q_INVOKABLE QJSValue departureMapArguments() const;
+    /** Map page arugments for an element that isn't a location change. */
+    Q_INVOKABLE QJSValue mapArguments() const;
 
     int documentCount() const;
 
